package musicrepos.mvc.controller;

import java.io.File;

import javax.servlet.RequestDispatcher;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import musicrepos.exception.UserNotLoggedException;
import musicrepos.mvc.model.Music;
import musicrepos.mvc.model.MusicDAO;
import musicrepos.mvc.model.User;
import musicrepos.util.FileSystemControl;
import musicrepos.util.MusicCreator;
import entagged.audioformats.AudioFile;
import entagged.audioformats.AudioFileIO;

public class SaveFile implements BusinessLogic {

	@Override
	public void execute(HttpServletRequest request, HttpServletResponse response) throws Exception {
		User currentUser = (User) request.getSession().getAttribute("sessionUser");

		if (currentUser == null) {
			throw new UserNotLoggedException();
		}

		String title = request.getParameter("title");
		String artist = request.getParameter("artist");
		String album = request.getParameter("album");
		String genre = request.getParameter("genre");
		String year = request.getParameter("year");
		String pathname = request.getParameter("pathname");

		File oldFile = new File(pathname);
		AudioFile audioFile = AudioFileIO.read(oldFile);

		audioFile.getTag().setTitle(title);
		audioFile.getTag().setArtist(artist);
		audioFile.getTag().setAlbum(album);
		audioFile.getTag().setGenre(genre);
		audioFile.getTag().setYear(year);

		audioFile.commit();

		AudioFileIO.write(audioFile);

		String baseDirectory = FileSystemControl.getMusicPath(request);
		String destinationDirectory = baseDirectory + "/" + artist + "/" + album + "/";

		if (!(new File(destinationDirectory).exists())) {
			boolean newDirectory = new File(destinationDirectory).mkdirs();

			if (!newDirectory) {
				throw new Exception("Could not create directory");
			}
		}

		String newPathname = destinationDirectory + title + ".mp3";
		File newFile = new File(newPathname);
		oldFile.renameTo(newFile);

		Music music = MusicCreator.createMusicFromTag(audioFile);
		MusicDAO musicDAO = new MusicDAO();

		String serverAddress = new String(request.getRequestURL());
		serverAddress = serverAddress.substring(0, serverAddress.lastIndexOf('/'));

		music.setPathname(serverAddress + "/music/" + artist + "/" + album + "/" + title + ".mp3");
		music.setUserId(currentUser.getId());

		musicDAO.persist(music);

		RequestDispatcher rd = request.getRequestDispatcher("/index.jsp");
		rd.forward(request, response);
	}
}
