package musicrepos.mvc.model;

import java.sql.Date;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

public class UserDAO extends DAO {

	public UserDAO() {
		super();

		tableName = "user";
	}

	public void persist(User user) throws SQLException {
		String sql = "insert into user (login, name, password, email, birthdate) values (?,?,?,?,?)";

		PreparedStatement preparedStatement = connection.prepareStatement(sql);

		preparedStatement.setString(1, user.getLogin());
		preparedStatement.setString(2, user.getName());
		preparedStatement.setString(3, user.getPassword());
		preparedStatement.setString(4, user.getEmail());
		Date birthdate = new Date(user.getBirthdate().getTime());
		preparedStatement.setDate(5, birthdate);

		preparedStatement.execute();
		preparedStatement.close();

	}

	public void merge(User user) throws SQLException {
		String sql = "update user set name = ?, password = ?, email = ?, birthdate = ? where id = ?";

		PreparedStatement preparedStatement = connection.prepareStatement(sql);

		preparedStatement.setString(1, user.getName());
		preparedStatement.setString(2, user.getPassword());
		preparedStatement.setString(3, user.getEmail());

		Date birthdate = new Date(user.getBirthdate().getTime());
		preparedStatement.setDate(4, birthdate);

		preparedStatement.setInt(5, user.getId());

		preparedStatement.executeUpdate();
		preparedStatement.close();

	}

	public void remove(User user) throws SQLException {
		PreparedStatement preparedStatement = connection.prepareStatement("remove from user where id = ?");

		preparedStatement.setInt(1, user.getId());

		preparedStatement.execute();
	}

	public List<User> getUser(String field, String value) throws SQLException {
		String sql = "select * from user";

		if (field != null && value != null) {
			sql = sql + " where " + field + " = '" + value + "'";
		}

		PreparedStatement preparedStatement = connection.prepareStatement(sql);
		ResultSet rs = preparedStatement.executeQuery();

		List<User> users = new ArrayList<User>();

		while (rs.next()) {
			User user = new User();
			user.setId(rs.getInt("id"));
			user.setName(rs.getString("name"));
			user.setLogin(rs.getString("login"));
			user.setPassword(rs.getString("password"));
			user.setEmail(rs.getString("email"));
			user.setBirthdate(rs.getDate("birthdate"));

			users.add(user);
		}

		rs.close();
		preparedStatement.close();

		return users;
	}

	public User getUser(int id) throws SQLException {
		List<User> users = this.getUser("id", Integer.toString(id));

		if (users.size() == 1) {
			return users.get(0);
		} else {
			return null;
		}
	}

	public User getUser(String login) throws SQLException {
		List<User> users = this.getUser("login", login);

		if (users.size() == 1) {
			return users.get(0);
		} else {
			return null;
		}
	}

	public List<User> getUsersList() throws SQLException {
		return getUser(null, null);
	}

	public boolean exists(String field, String value) throws SQLException {
		List<User> users = this.getUser(field, value);

		return (users.size() > 0);
	}
}
